@@ -24,10 +24,16 @@ class Reversor:
         return other.obj < self.obj
 
 
+def get_sorted_pkg_list(distributions: Iterable[Package], options: Options, now: datetime) -> Iterable[Package]:
+    if options.sort in ["a", "alphabetic"]:
+        return sorted(distributions, key=lambda v: v.name.lower())
+    return sorted(distributions, key=lambda v: (v.last_release_at or now, Reversor(v.name)), reverse=True)
+
+
 def print_tree(distributions: Iterable[Package], options: Options) -> None:
     now = datetime.now(timezone.utc)
     tree = Tree(f"🐍 Distributions within {escape(str(options.python))}", guide_style="cyan")
-    for pkg in sorted(distributions, key=lambda v: (v.last_release_at or now, Reversor(v.name)), reverse=True):
+    for pkg in get_sorted_pkg_list(distributions, options, now):
         text = Text(pkg.name, "yellow")
         text.stylize(f"link https://pypi.org/project/{pkg.name}/#history")
         text.append(" ", "white")
